==> nextcloud-29.0.12.tgz: nextcloud/apps/encryption/l10n/hr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Nedostaje zaporka ključa za oporavak",
    "Please repeat the recovery key password" : "Ponovite zaporku ključa za oporavak",
    "Repeated recovery key password does not match the provided recovery key password" : "Ponovljena zaporka ključa za oporavak ne podudara se s danom zaporkom ključa za oporavak",
    "Recovery key successfully enabled" : "Ključ za oporavak uspješno omogućen",
    "Could not enable recovery key. Please check your recovery key password!" : "Ključ za oporavak nije moguće omogućiti. Provjerite svoju zaporku ključa za oporavak!",
    "Recovery key successfully disabled" : "Ključ za oporavak uspješno onemogućen",
    "Could not disable recovery key. Please check your recovery key password!" : "Ključ za oporavak nije moguće onemogućiti. Provjerite svoju zaporku ključa za oporavak!",
    "Missing parameters" : "Nedostaju parametri",
    "Please provide the old recovery password" : "Unesite staru zaporku za oporavak",
    "Please provide a new recovery password" : "Unesite novu zaporku za oporavak",
    "Please repeat the new recovery password" : "Ponovite novu zaporku za oporavak",
    "Password successfully changed." : "Zaporka uspješno promijenjena.",
    "Could not change the password. Maybe the old password was not correct." : "Zaporku nije moguće promijeniti. Možda je stara zaporka bila neispravna.",
    "Recovery Key disabled" : "Onemogućen ključ za oporavak",
    "Recovery Key enabled" : "Omogućen ključ za oporavak",
    "Could not enable the recovery key, please try again or contact your administrator" : "Neuspješno omogućivanje ključa za oporavak, pokušajte ponovno ili se obratite svom administratoru",
    "Could not update the private key password." : "Nije moguće ažurirati zaporku privatnog ključa.",
    "The old password was not correct, please try again." : "Stara zaporka nije bila ispravna, pokušajte ponovo.",
    "The current log-in password was not correct, please try again." : "Trenutačna zaporka za prijavu nije bila ispravna, pokušajte ponovo.",
    "Private key password successfully updated." : "Zaporka privatnog ključa uspješno ažurirana.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nevažeći privatni ključ za aplikaciju za šifriranje. Ažurirajte zaporku privatnog ključa u svojim osobnim postavkama kako biste ponovno omogućili pristup šifriranim datotekama.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikacija za šifriranje je omogućena, ali se ključevi nisu inicijalizirali. Odjavite se i ponovno se prijavite.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Omogućite šifriranje na poslužitelju u postavkama administratora kako biste se mogli koristiti modulom za šifriranje.",
    "Encryption app is enabled and ready" : "Aplikacija za šifriranje je omogućena i spremna na uporabu",
    "Bad Signature" : "Nevažeći potpis",
    "Missing Signature" : "Nedostaje potpis",
    "one-time password for server-side-encryption" : "jednokratna zaporka za šifriranje na poslužitelju",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ovu datoteku nije moguće dešifrirati, vjerojatno je riječ o dijeljenoj datoteci. Zatražite od vlasnika datoteke da je ponovo podijeli s vama.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ovu datoteku nije moguće čitati, vjerojatno je riječ o dijeljenoj datoteci. Zatražite od vlasnika datoteke da je ponovo podijeli s vama.",
    "Default encryption module" : "Zadani modul za šifriranje",
    "Default encryption module for server-side encryption" : "Zadani modul za šifriranje na poslužitelju",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacija za šifriranje je omogućena, ali se ključevi nisu inicijalizirali, odjavite se i ponovno se prijavite",
    "Encrypt the home storage" : "Šifrirajte kućnu pohranu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Omogućavanjem ove opcije šifriraju se sve datoteke smještene u glavnoj pohrani, a u protivnom se šifriraju samo datoteke u vanjskoj pohrani",
    "Enable recovery key" : "Omogući ključ za oporavak",
    "Disable recovery key" : "Onemogući ključ za oporavak",
    "Recovery key password" : "Zaporka ključa za oporavak",
    "Repeat recovery key password" : "Ponovite zaporku ključa za oporavak",
    "Change recovery key password:" : "Promijenite zaporku ključa za oporavak:",
    "Old recovery key password" : "Stara zaporka ključa za oporavak",
    "New recovery key password" : "Nova zaporka ključa za oporavak",
    "Repeat new recovery key password" : "Ponovite novu zaporku ključa za oporavak",
    "Change Password" : "Promijeni zaporku",
    "Basic encryption module" : "Osnovni modul za šifriranje",
    "Your private key password no longer matches your log-in password." : "Zaporka vašeg privatnog ključa više se ne podudara s vašom zaporkom za prijavu.",
    "Set your old private key password to your current log-in password:" : "Promijenite svoju staru zaporku privatnog ključa u postojeću zaporku za prijavu:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ako se ne sjećate svoje stare zaporke, zatražite od administratora da oporavi vaše datoteke.",
    "Old log-in password" : "Stara zaporka za prijavu",
    "Current log-in password" : "Aktualna zaporka za prijavu",
    "Update Private Key Password" : "Ažuriraj zaporku privatnog ključa",
    "Enable password recovery:" : "Omogući oporavak zaporke:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "U slučaju gubitka zaporke, aktiviranje ove mogućnosti ponovno će vam pribaviti pristup vašim šifriranim datotekama",
    "Enabled" : "Omogućeno",
    "Disabled" : "Onemogućeno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/encryption/l10n/hr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Nedostaje zaporka ključa za oporavak",
    "Please repeat the recovery key password" : "Ponovite zaporku ključa za oporavak",
    "Repeated recovery key password does not match the provided recovery key password" : "Ponovljena zaporka ključa za oporavak ne podudara se s danom zaporkom ključa za oporavak",
    "Recovery key successfully enabled" : "Ključ za oporavak uspješno omogućen",
    "Could not enable recovery key. Please check your recovery key password!" : "Ključ za oporavak nije moguće omogućiti. Provjerite svoju zaporku ključa za oporavak!",
    "Recovery key successfully disabled" : "Ključ za oporavak uspješno onemogućen",
    "Could not disable recovery key. Please check your recovery key password!" : "Ključ za oporavak nije moguće onemogućiti. Provjerite svoju zaporku ključa za oporavak!",
    "Missing parameters" : "Nedostaju parametri",
    "Please provide the old recovery password" : "Unesite staru zaporku za oporavak",
    "Please provide a new recovery password" : "Unesite novu zaporku za oporavak",
    "Please repeat the new recovery password" : "Ponovite novu zaporku za oporavak",
    "Password successfully changed." : "Zaporka uspješno promijenjena.",
    "Could not change the password. Maybe the old password was not correct." : "Zaporku nije moguće promijeniti. Možda je stara zaporka bila neispravna.",
    "Recovery Key disabled" : "Onemogućen ključ za oporavak",
    "Recovery Key enabled" : "Omogućen ključ za oporavak",
    "Could not enable the recovery key, please try again or contact your administrator" : "Neuspješno omogućivanje ključa za oporavak, pokušajte ponovno ili se obratite svom administratoru",
    "Could not update the private key password." : "Nije moguće ažurirati zaporku privatnog ključa.",
    "The old password was not correct, please try again." : "Stara zaporka nije bila ispravna, pokušajte ponovo.",
    "The current log-in password was not correct, please try again." : "Trenutačna zaporka za prijavu nije bila ispravna, pokušajte ponovo.",
    "Private key password successfully updated." : "Zaporka privatnog ključa uspješno ažurirana.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nevažeći privatni ključ za aplikaciju za šifriranje. Ažurirajte zaporku privatnog ključa u svojim osobnim postavkama kako biste ponovno omogućili pristup šifriranim datotekama.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikacija za šifriranje je omogućena, ali se ključevi nisu inicijalizirali. Odjavite se i ponovno se prijavite.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Omogućite šifriranje na poslužitelju u postavkama administratora kako biste se mogli koristiti modulom za šifriranje.",
    "Encryption app is enabled and ready" : "Aplikacija za šifriranje je omogućena i spremna na uporabu",
    "Bad Signature" : "Nevažeći potpis",
    "Missing Signature" : "Nedostaje potpis",
    "one-time password for server-side-encryption" : "jednokratna zaporka za šifriranje na poslužitelju",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ovu datoteku nije moguće dešifrirati, vjerojatno je riječ o dijeljenoj datoteci. Zatražite od vlasnika datoteke da je ponovo podijeli s vama.",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Ovu datoteku nije moguće čitati, vjerojatno je riječ o dijeljenoj datoteci. Zatražite od vlasnika datoteke da je ponovo podijeli s vama.",
    "Default encryption module" : "Zadani modul za šifriranje",
    "Default encryption module for server-side encryption" : "Zadani modul za šifriranje na poslužitelju",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacija za šifriranje je omogućena, ali se ključevi nisu inicijalizirali, odjavite se i ponovno se prijavite",
    "Encrypt the home storage" : "Šifrirajte kućnu pohranu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Omogućavanjem ove opcije šifriraju se sve datoteke smještene u glavnoj pohrani, a u protivnom se šifriraju samo datoteke u vanjskoj pohrani",
    "Enable recovery key" : "Omogući ključ za oporavak",
    "Disable recovery key" : "Onemogući ključ za oporavak",
    "Recovery key password" : "Zaporka ključa za oporavak",
    "Repeat recovery key password" : "Ponovite zaporku ključa za oporavak",
    "Change recovery key password:" : "Promijenite zaporku ključa za oporavak:",
    "Old recovery key password" : "Stara zaporka ključa za oporavak",
    "New recovery key password" : "Nova zaporka ključa za oporavak",
    "Repeat new recovery key password" : "Ponovite novu zaporku ključa za oporavak",
    "Change Password" : "Promijeni zaporku",
    "Basic encryption module" : "Osnovni modul za šifriranje",
    "Your private key password no longer matches your log-in password." : "Zaporka vašeg privatnog ključa više se ne podudara s vašom zaporkom za prijavu.",
    "Set your old private key password to your current log-in password:" : "Promijenite svoju staru zaporku privatnog ključa u postojeću zaporku za prijavu:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ako se ne sjećate svoje stare zaporke, zatražite od administratora da oporavi vaše datoteke.",
    "Old log-in password" : "Stara zaporka za prijavu",
    "Current log-in password" : "Aktualna zaporka za prijavu",
    "Update Private Key Password" : "Ažuriraj zaporku privatnog ključa",
    "Enable password recovery:" : "Omogući oporavak zaporke:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "U slučaju gubitka zaporke, aktiviranje ove mogućnosti ponovno će vam pribaviti pristup vašim šifriranim datotekama",
    "Enabled" : "Omogućeno",
    "Disabled" : "Onemogućeno",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Ključ za oporavak dodatni je ključ za šifriranje koji se upotrebljava za šifriranje datoteka. Omogućuje oporavak datoteka kada korisnik zaboravi svoju zaporku."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
